@@ -20,10 +20,14 @@ GOOGLE_LANGUAGES_TO_CODES = {
     "amharic": "am",
     "arabic": "ar",
     "armenian": "hy",
+    "assamese": "as",
+    "aymara": "ay",
     "azerbaijani": "az",
+    "bambara": "bm",
     "basque": "eu",
     "belarusian": "be",
     "bengali": "bn",
+    "bhojpuri": "bho",
     "bosnian": "bs",
     "bulgarian": "bg",
     "catalan": "ca",
@@ -35,10 +39,13 @@ GOOGLE_LANGUAGES_TO_CODES = {
     "croatian": "hr",
     "czech": "cs",
     "danish": "da",
+    "dhivehi": "dv",
+    "dogri": "doi",
     "dutch": "nl",
     "english": "en",
     "esperanto": "eo",
     "estonian": "et",
+    "ewe": "ee",
     "filipino": "tl",
     "finnish": "fi",
     "french": "fr",
@@ -47,6 +54,7 @@ GOOGLE_LANGUAGES_TO_CODES = {
     "georgian": "ka",
     "german": "de",
     "greek": "el",
+    "guarani": "gn",
     "gujarati": "gu",
     "haitian creole": "ht",
     "hausa": "ha",
@@ -57,6 +65,7 @@ GOOGLE_LANGUAGES_TO_CODES = {
     "hungarian": "hu",
     "icelandic": "is",
     "igbo": "ig",
+    "ilocano": "ilo",
     "indonesian": "id",
     "irish": "ga",
     "italian": "it",
@@ -66,35 +75,47 @@ GOOGLE_LANGUAGES_TO_CODES = {
     "kazakh": "kk",
     "khmer": "km",
     "kinyarwanda": "rw",
+    "konkani": "gom",
     "korean": "ko",
-    "kurdish": "ku",
+    "krio": "kri",
+    "kurdish (kurmanji)": "ku",
+    "kurdish (sorani)": "ckb",
     "kyrgyz": "ky",
     "lao": "lo",
     "latin": "la",
     "latvian": "lv",
+    "lingala": "ln",
     "lithuanian": "lt",
+    "luganda": "lg",
     "luxembourgish": "lb",
     "macedonian": "mk",
+    "maithili": "mai",
     "malagasy": "mg",
     "malay": "ms",
     "malayalam": "ml",
     "maltese": "mt",
     "maori": "mi",
     "marathi": "mr",
+    "meiteilon (manipuri)": "mni-Mtei",
+    "mizo": "lus",
     "mongolian": "mn",
     "myanmar": "my",
     "nepali": "ne",
     "norwegian": "no",
-    "odia": "or",
+    "odia (oriya)": "or",
+    "oromo": "om",
     "pashto": "ps",
     "persian": "fa",
     "polish": "pl",
     "portuguese": "pt",
     "punjabi": "pa",
+    "quechua": "qu",
     "romanian": "ro",
     "russian": "ru",
     "samoan": "sm",
+    "sanskrit": "sa",
     "scots gaelic": "gd",
+    "sepedi": "nso",
     "serbian": "sr",
     "sesotho": "st",
     "shona": "sn",
@@ -112,8 +133,11 @@ GOOGLE_LANGUAGES_TO_CODES = {
     "tatar": "tt",
     "telugu": "te",
     "thai": "th",
+    "tigrinya": "ti",
+    "tsonga": "ts",
     "turkish": "tr",
     "turkmen": "tk",
+    "twi": "ak",
     "ukrainian": "uk",
     "urdu": "ur",
     "uyghur": "ug",
